==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebTabGroupPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebTabGroupPaneDescription } from "./WebTabGroupPaneDescription";
/**
 * @hidden
 */
var WebTabGroupPaneDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabGroupPaneDescriptionMetadata, _super);
    function WebTabGroupPaneDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabGroupPaneDescriptionMetadata.b = function (a) {
        if (WebTabGroupPaneDescriptionMetadata.a == null) {
            WebTabGroupPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabGroupPaneDescriptionMetadata.c(WebTabGroupPaneDescriptionMetadata.a);
        }
        if (a.g(WebTabGroupPaneDescriptionMetadata.a)) {
            return;
        }
        a.s(WebTabGroupPaneDescriptionMetadata.a);
    };
    WebTabGroupPaneDescriptionMetadata.c = function (a) {
        WebDockManagerPaneDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:TabGroupPane");
        a.item("Id", "String");
        a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
        a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        a.item("Size", "Number:double");
        a.item("SelectedIndex", "Number:double");
        a.item("AllowEmpty", "Boolean");
    };
    WebTabGroupPaneDescriptionMetadata.d = function (a) {
        WebTabGroupPaneDescriptionMetadata.b(a);
        a.u("WebTabGroupPane", function () { return new WebTabGroupPaneDescription(); });
        a.t("WebTabGroupPane", WebTabGroupPaneDescriptionMetadata.a);
    };
    WebTabGroupPaneDescriptionMetadata.$t = markType(WebTabGroupPaneDescriptionMetadata, 'WebTabGroupPaneDescriptionMetadata');
    WebTabGroupPaneDescriptionMetadata.a = null;
    return WebTabGroupPaneDescriptionMetadata;
}(Base));
export { WebTabGroupPaneDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebTabGroupPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebTabGroupPaneDescription } from "./WebTabGroupPaneDescription";
/**
 * @hidden
 */
var WebTabGroupPaneDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabGroupPaneDescriptionMetadata, _super);
    function WebTabGroupPaneDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabGroupPaneDescriptionMetadata.b = function (a) {
        if (WebTabGroupPaneDescriptionMetadata.a == null) {
            WebTabGroupPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabGroupPaneDescriptionMetadata.c(WebTabGroupPaneDescriptionMetadata.a);
        }
        if (a.j(WebTabGroupPaneDescriptionMetadata.a)) {
            return;
        }
        a.y(WebTabGroupPaneDescriptionMetadata.a);
    };
    WebTabGroupPaneDescriptionMetadata.c = function (a) {
        WebDockManagerPaneDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:TabGroupPane");
        a.item("Id", "String");
        a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
        a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        a.item("Size", "Number:double");
        a.item("SelectedIndex", "Number:double");
        a.item("AllowEmpty", "Boolean");
    };
    WebTabGroupPaneDescriptionMetadata.d = function (a) {
        WebTabGroupPaneDescriptionMetadata.b(a);
        a.aa("WebTabGroupPane", function () { return new WebTabGroupPaneDescription(); });
        a.z("WebTabGroupPane", WebTabGroupPaneDescriptionMetadata.a);
    };
    WebTabGroupPaneDescriptionMetadata.$t = markType(WebTabGroupPaneDescriptionMetadata, 'WebTabGroupPaneDescriptionMetadata');
    WebTabGroupPaneDescriptionMetadata.a = null;
    return WebTabGroupPaneDescriptionMetadata;
}(Base));
export { WebTabGroupPaneDescriptionMetadata };
